# 🌐 STVTermux

**STVTermux** là một thư viện Python cho phép bạn đăng nhập và đăng ký tài khoản thông qua **Firebase Realtime Database**.  
Thư viện được tối ưu để sử dụng trong **Termux**, với lệnh CLI `stv` để mở giao diện trực tiếp trên terminal.  

---

## 🚀 Cài đặt

```bash
pip install STVTermux
```